@@ -8,29 +8,31 @@
 #ifndef CONNECTIVITYACTION_H
 #define CONNECTIVITYACTION_H
 
-#include <QMenu>
-#include <QFileDialog>
 #include <KLocalizedString>
+#include <QFileDialog>
+#include <QMenu>
 
 #include "interfaces/dbusinterfaces.h"
 
 #include <dbushelper.h>
 
-namespace connectivity_action {
-    const QStringList networkTypesWithIcons {   // contains the name of network types that have an associated icon in Breeze-icons
-        QStringLiteral("EDGE"),
-        QStringLiteral("GPRS"),
-        QStringLiteral("HSPA"),
-        QStringLiteral("LTE"),
-        QStringLiteral("UMTS"),
-        };
+namespace connectivity_action
+{
+const QStringList networkTypesWithIcons{
+    // contains the name of network types that have an associated icon in Breeze-icons
+    QStringLiteral("EDGE"),
+    QStringLiteral("GPRS"),
+    QStringLiteral("HSPA"),
+    QStringLiteral("LTE"),
+    QStringLiteral("UMTS"),
+};
 }
 
 class ConnectivityAction : public QAction
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-    ConnectivityAction(DeviceDbusInterface* device);
+    ConnectivityAction(DeviceDbusInterface *device);
     void update();
 private Q_SLOTS:
     void setCellularNetworkStrength(int cellularNetworkStrength);
