@@ -9,11 +9,7 @@
 
 #include <QCursor>
 #include <QDebug>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
 #include <private/qtx11extras_p.h>
-#endif
 
 #include <X11/extensions/XTest.h>
 #include <X11/keysym.h>
