@@ -13,12 +13,8 @@
 #include <KPluginFactory>
 #if !defined(Q_OS_WIN) && !defined(Q_OS_MAC)
 #include <KStartupInfo>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
 #include <private/qtx11extras_p.h>
 #endif
-#endif
 
 K_PLUGIN_CLASS_WITH_JSON(NotificationsPlugin, "kdeconnect_notifications.json")
 
